==> cerebro-refactoring-0.1.3.5.tar.gz: cerebro-refactoring-0.1.3.5/cerebro/refactoring/datastructs/stack.py <==
# ------------------------------------------------------------------------------
#  MIT License
#
#  Copyright (c) 2021 Hieu Pham. All rights reserved.
#
#  Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# ------------------------------------------------------------------------------

from typing import Any
from cerebro.refactoring.objects import Object


class Stack(Object):
    """
    Stack is an implementation of first in last out structure.
    ---------
    @author:    Hieu Pham.
    @created:   13.10.2021.
    @updated:   13.10.2021.
    """

    def __init__(self, **kwargs):
        """
        Create new object.
        :param kwargs:  keyword arguments.
        """
        super().__init__(**kwargs)
        self._stack = list()

    def push(self, obj: Any = None, **kwargs):
        """
        Push object into stack.
        :param obj:     object to be pushed.
        :param kwargs:  keyword arguments.
        :return:        object.
        """
        if obj is None:
            return None
        else:
            self._stack.append(obj)
            return obj

    def pop(self, **kwargs):
        """
        Pop object from stack.
        :param kwargs:  keyword arguments.
        :return:        object.
        """
        if len(self._stack) == 0:
            return None
        else:
            return self._stack.pop()

    def clean(self, **kwargs):
        """
        Pop all objects from stack.
        :param kwargs:  keyword arguments.
        :return:        object.
        """
        return [self._stack.pop() for i in range(len(self._stack))]

==> cerebro-refactoring-0.1.3.9.1.tar.gz: cerebro-refactoring-0.1.3.9.1/cerebro/refactoring/datastructs/stack.py <==
# ------------------------------------------------------------------------------
#  MIT License
#
#  Copyright (c) 2021 Hieu Pham. All rights reserved.
#
#  Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# ------------------------------------------------------------------------------

from typing import Any
from cerebro.refactoring import Object


class Stack(Object):
    """
    Stack is an implementation of first in last out structure.
    ---------
    @author:    Hieu Pham.
    @created:   13.10.2021.
    @updated:   13.10.2021.
    """

    def __init__(self, **kwargs):
        """
        Create new object.
        :param kwargs:  keyword arguments.
        """
        super().__init__(**kwargs)
        self._stack = list()

    def push(self, obj: Any = None, **kwargs):
        """
        Push object into stack.
        :param obj:     object to be pushed.
        :param kwargs:  keyword arguments.
        :return:        object.
        """
        if obj is None:
            return None
        else:
            self._stack.append(obj)
            return obj

    def pop(self, **kwargs):
        """
        Pop object from stack.
        :param kwargs:  keyword arguments.
        :return:        object.
        """
        if len(self._stack) == 0:
            return None
        else:
            return self._stack.pop()

    def clean(self, **kwargs):
        """
        Pop all objects from stack.
        :param kwargs:  keyword arguments.
        :return:        object.
        """
        return [self._stack.pop() for i in range(len(self._stack))]
